@@ -29,6 +29,7 @@ from typing import (
     cast,
 )
 from urllib.parse import urlparse, urlunparse
+from urllib.request import pathname2url
 from zipfile import ZipFile
 
 import pytest
@@ -1379,6 +1380,10 @@ class ScriptFactory(Protocol):
 
 CertFactory = Callable[[], str]
 
+# -------------------------------------------------------------------------
+# Accommodations for Windows path and URL changes in recent Python releases
+# -------------------------------------------------------------------------
+
 # versions containing fix/backport from https://github.com/python/cpython/pull/113563
 # which changed the behavior of `urllib.parse.urlun{parse,split}`
 url = "////path/to/file"
@@ -1394,3 +1399,15 @@ skip_needs_old_urlun_behavior_win = pytest.mark.skipif(
     sys.platform != "win32" or has_new_urlun_behavior,
     reason="testing windows behavior for older CPython",
 )
+
+# Trailing slashes are now preserved on Windows, matching POSIX behaviour.
+# BPO: https://github.com/python/cpython/issues/126212
+does_pathname2url_preserve_trailing_slash = pathname2url("C:/foo/").endswith("/")
+skip_needs_new_pathname2url_trailing_slash_behavior_win = pytest.mark.skipif(
+    sys.platform != "win32" or not does_pathname2url_preserve_trailing_slash,
+    reason="testing windows (pathname2url) behavior for newer CPython",
+)
+skip_needs_old_pathname2url_trailing_slash_behavior_win = pytest.mark.skipif(
+    sys.platform != "win32" or does_pathname2url_preserve_trailing_slash,
+    reason="testing windows (pathname2url) behavior for older CPython",
+)
